@@ -255,6 +255,8 @@ REST_API_VERSION_HISTORY = """REST API Version History:
     * 2.93 - Add support for volume backed server rebuild.
     * 2.94 - Allow FQDN in server hostname.
     * 2.95 - Evacuate will now stop instance at destination.
+    * 2.96 - Add support for returning pinned_availability_zone in
+             ``server show`` and ``server list --long`` responses.
 """
 
 # The minimum and maximum versions of the API supported
@@ -263,7 +265,7 @@ REST_API_VERSION_HISTORY = """REST API Version History:
 # Note(cyeoh): This only applies for the v2.1 API once microversions
 # support is fully merged. It does not affect the V2 API.
 _MIN_API_VERSION = '2.1'
-_MAX_API_VERSION = '2.95'
+_MAX_API_VERSION = '2.96'
 DEFAULT_API_VERSION = _MIN_API_VERSION
 
 # Almost all proxy APIs which are related to network, images and baremetal
