@@ -25,10 +25,6 @@ from nova.policies import ips as ips_policies
 
 class IPsController(wsgi.Controller):
     """The servers addresses API controller for the OpenStack API."""
-    # Note(gmann): here using V2 view builder instead of V3 to have V2.1
-    # server ips response same as V2 which does not include "OS-EXT-IPS:type"
-    # & "OS-EXT-IPS-MAC:mac_addr". If needed those can be added with
-    # microversion by using V2.1 view builder.
     _view_builder_class = views_addresses.ViewBuilder
 
     def __init__(self):
@@ -38,19 +34,21 @@ class IPsController(wsgi.Controller):
     @wsgi.expected_errors(404)
     def index(self, req, server_id):
         context = req.environ["nova.context"]
-        context.can(ips_policies.POLICY_ROOT % 'index')
         instance = common.get_instance(self._compute_api, context, server_id)
+        context.can(ips_policies.POLICY_ROOT % 'index',
+                    target={'project_id': instance.project_id})
         networks = common.get_networks_for_instance(context, instance)
-        return self._view_builder.index(networks)
+        return self._view_builder.index(req, networks)
 
     @wsgi.expected_errors(404)
     def show(self, req, server_id, id):
         context = req.environ["nova.context"]
-        context.can(ips_policies.POLICY_ROOT % 'show')
         instance = common.get_instance(self._compute_api, context, server_id)
+        context.can(ips_policies.POLICY_ROOT % 'show',
+                    target={'project_id': instance.project_id})
         networks = common.get_networks_for_instance(context, instance)
         if id not in networks:
             msg = _("Instance is not a member of specified network")
             raise exc.HTTPNotFound(explanation=msg)
 
-        return self._view_builder.show(networks[id], id)
+        return self._view_builder.show(req, networks[id], id)
