@@ -84,6 +84,59 @@ Agent. With the Spice agent installed the following features are enabled:
 * Better mouse integration - The mouse can be captured and released without
   needing to click inside the console or press keys to release it. The
   performance of mouse movement is also improved.
+"""),
+    cfg.StrOpt('image_compression',
+        advanced=True,
+        choices=[
+            ('auto_glz', 'enable image compression mode to choose between glz '
+             'and quic algorithm, based on image properties'),
+            ('auto_lz', 'enable image compression mode to choose between lz '
+             'and quic algorithm, based on image properties'),
+            ('quic', 'enable image compression based on the SFALIC algorithm'),
+            ('glz', 'enable image compression using lz with history based '
+             'global dictionary'),
+            ('lz', 'enable image compression with the Lempel-Ziv algorithm'),
+            ('off', 'disable image compression')
+        ],
+        help="""
+Configure the SPICE image compression (lossless).
+"""),
+    cfg.StrOpt('jpeg_compression',
+        advanced=True,
+        choices=[
+            ('auto', 'enable JPEG image compression automatically'),
+            ('never', 'disable JPEG image compression'),
+            ('always', 'enable JPEG image compression')
+        ],
+        help="""
+Configure the SPICE wan image compression (lossy for slow links).
+"""),
+    cfg.StrOpt('zlib_compression',
+        advanced=True,
+        choices=[
+            ('auto', 'enable zlib image compression automatically'),
+            ('never', 'disable zlib image compression'),
+            ('always', 'enable zlib image compression')
+        ],
+        help="""
+Configure the SPICE wan image compression (lossless for slow links).
+"""),
+    cfg.BoolOpt('playback_compression',
+        advanced=True,
+        help="""
+Enable the SPICE audio stream compression (using celt).
+"""),
+    cfg.StrOpt('streaming_mode',
+        advanced=True,
+        choices=[
+            ('filter', 'SPICE server adds additional filters to decide if '
+             'video streaming should be activated'),
+            ('all', 'any fast-refreshing window can be encoded into a video '
+             'stream'),
+            ('off', 'no video detection and (lossy) compression is performed')
+        ],
+        help="""
+Configure the SPICE video stream detection and (lossy) compression.
 """),
     cfg.URIOpt('html5proxy_base_url',
         default='http://127.0.0.1:6082/spice_auto.html',
@@ -142,17 +195,6 @@ Related options:
   The proxy client must be able to access the address specified in
   ``server_listen`` using the value of this option.
 """),
-    cfg.StrOpt('keymap',
-        default='en-us',
-        help="""
-A keyboard layout which is supported by the underlying hypervisor on this
-node.
-
-Possible values:
-* This is usually an 'IETF language tag' (default is 'en-us'). If you
-  use QEMU as hypervisor, you should find the list of supported keyboard
-  layouts at /usr/share/qemu/keymaps.
-""")
 ]
 
 ALL_OPTS.extend(CLI_OPTS)
