@@ -37,6 +37,9 @@ from nova import exception
 from nova.i18n import _
 from nova import objects
 
+from oslo_utils import timeutils
+import threading
+
 # Location of WebSockifyServer class in websockify v0.9.0
 websockifyserver = importutils.try_import('websockify.websockifyserver')
 
@@ -147,6 +150,20 @@ class NovaProxyRequestHandler(websockify.ProxyRequestHandler):
 
         return connect_info
 
+    def _close_connection(self, tsock, host, port):
+        """takes target socket and close the connection.
+        """
+        try:
+            tsock.shutdown(socket.SHUT_RDWR)
+        except OSError:
+            pass
+        finally:
+            if tsock.fileno() != -1:
+                tsock.close()
+                self.vmsg(_("%(host)s:%(port)s: "
+                    "Websocket client or target closed") %
+                    {'host': host, 'port': port})
+
     def new_websocket_client(self):
         """Called after a new WebSocket connection has been established."""
         # Reopen the eventlet hub to make sure we don't share an epoll
@@ -260,14 +277,15 @@ class NovaProxyRequestHandler(websockify.ProxyRequestHandler):
 
         # Start proxying
         try:
+            if CONF.consoleauth.enforce_session_timeout:
+                conn_timeout = connect_info.expires - timeutils.utcnow_ts()
+                LOG.info('%s seconds to terminate connection.', conn_timeout)
+                threading.Timer(conn_timeout, self._close_connection,
+                          [tsock, host, port]).start()
+
             self.do_proxy(tsock)
         except Exception:
-            if tsock:
-                tsock.shutdown(socket.SHUT_RDWR)
-                tsock.close()
-                self.vmsg(_("%(host)s:%(port)s: "
-                          "Websocket client or target closed") %
-                          {'host': host, 'port': port})
+            self._close_connection(tsock, host, port)
             raise
 
     def socket(self, *args, **kwargs):
@@ -305,7 +323,7 @@ class NovaWebSocketProxy(websockify.WebSocketProxy):
         # ssl_options unset to default to the underlying system defaults.
         # We do this to avoid using websockify's behaviour for 'default'
         # in select_ssl_version(), which hardcodes the versions to be
-        # quite relaxed and prevents us from using sytem crypto policies.
+        # quite relaxed and prevents us from using system crypto policies.
         ssl_min_version = kwargs.pop('ssl_minimum_version', None)
         if ssl_min_version and ssl_min_version != 'default':
             kwargs['ssl_options'] = websockify.websocketproxy. \
