@@ -126,10 +126,12 @@ class ImageMetaPropsPayload(base.NotificationPayloadBase):
     # Version 1.7: Added 'hw_input_bus' field
     # Version 1.8: Added 'bochs' as an option to 'hw_video_model'
     # Version 1.9: Added 'hw_emulation_architecture' field
-    VERSION = '1.9'
-
-    SCHEMA = {
-        k: ('image_meta_props', k) for k in image_meta.ImageMetaProps.fields}
+    # Version 1.10: Added 'hw_ephemeral_encryption' and
+    #                     'hw_ephemeral_encryption_format' fields
+    # Version 1.11: Added 'hw_locked_memory' field
+    # Version 1.12: Added 'hw_viommu_model' field
+    # Version 1.13: Added 'hw_virtio_packed_ring' field
+    VERSION = '1.13'
 
     # NOTE(efried): This logic currently relies on all of the fields of
     # ImageMetaProps being initialized with no arguments. See the docstring.
@@ -138,7 +140,11 @@ class ImageMetaPropsPayload(base.NotificationPayloadBase):
     #  But it is not clear that OVO can tolerate the same *instance* of a type
     #  class being used in more than one place.
     fields = {
-        k: v.__class__() for k, v in image_meta.ImageMetaProps.fields.items()}
+        k: v.__class__() for k, v in image_meta.ImageMetaProps.fields.items()
+            if k not in ('hw_ephemeral_encryption_secret_uuid',)}
+
+    SCHEMA = {
+        k: ('image_meta_props', k) for k in fields}
 
     def __init__(self, image_meta_props):
         super(ImageMetaPropsPayload, self).__init__()
