@@ -260,6 +260,14 @@ class BlockDeviceType(BaseNovaEnum):
     ALL = (CDROM, DISK, FLOPPY, FS, LUN)
 
 
+class BlockDeviceEncryptionFormatType(BaseNovaEnum):
+    PLAIN = 'plain'
+    LUKS = 'luks'
+    LUKSv2 = 'luksv2'
+
+    ALL = (PLAIN, LUKS, LUKSv2)
+
+
 class ConfigDrivePolicy(BaseNovaEnum):
     OPTIONAL = "optional"
     MANDATORY = "mandatory"
@@ -518,6 +526,25 @@ class RNGModel(BaseNovaEnum):
     ALL = (VIRTIO,)
 
 
+class ShareMappingStatus(BaseNovaEnum):
+    """Represents the possible status of a share mapping"""
+
+    ACTIVE = "active"
+    INACTIVE = "inactive"
+    ERROR = "error"
+
+    ALL = (ACTIVE, INACTIVE, ERROR)
+
+
+class ShareMappingProto(BaseNovaEnum):
+    """Represents the possible protocol used by a share mapping"""
+
+    NFS = "NFS"
+    CEPHFS = "CEPHFS"
+
+    ALL = (NFS, CEPHFS)
+
+
 class TPMModel(BaseNovaEnum):
 
     TIS = "tpm-tis"
@@ -533,6 +560,13 @@ class TPMVersion(BaseNovaEnum):
     ALL = (v1_2, v2_0)
 
 
+class MaxPhyAddrMode(BaseNovaEnum):
+    PASSTHROUGH = "passthrough"
+    EMULATE = "emulate"
+
+    ALL = (PASSTHROUGH, EMULATE)
+
+
 class SCSIModel(BaseNovaEnum):
 
     BUSLOGIC = "buslogic"
@@ -608,6 +642,16 @@ class VIFModel(BaseNovaEnum):
         return super(VIFModel, self).coerce(obj, attr, value)
 
 
+class VIOMMUModel(BaseNovaEnum):
+
+    INTEL = 'intel'
+    SMMUV3 = 'smmuv3'
+    VIRTIO = 'virtio'
+    AUTO = 'auto'
+
+    ALL = (INTEL, SMMUV3, VIRTIO, AUTO)
+
+
 class VMMode(BaseNovaEnum):
     """Represents possible vm modes for instances.
 
@@ -790,8 +834,8 @@ class DiskFormat(BaseNovaEnum):
     ALL = (RBD, LVM, QCOW2, RAW, PLOOP, VHD, VMDK, VDI, ISO)
 
 
-# TODO(stephenfin): Remove the xenapi value when we bump the 'Diagnostics'
-# object (the only user of this enum) to 2.0
+# TODO(stephenfin): Remove the xenapi and hyperv value when we bump the
+# 'Diagnostics' object (the only user of this enum) to 2.0
 class HypervisorDriver(BaseNovaEnum):
     LIBVIRT = "libvirt"
     XENAPI = "xenapi"
@@ -1197,6 +1241,10 @@ class BlockDeviceTypeField(BaseEnumField):
     AUTO_TYPE = BlockDeviceType()
 
 
+class BlockDeviceEncryptionFormatTypeField(BaseEnumField):
+    AUTO_TYPE = BlockDeviceEncryptionFormatType()
+
+
 class ConfigDrivePolicyField(BaseEnumField):
     AUTO_TYPE = ConfigDrivePolicy()
 
@@ -1253,6 +1301,10 @@ class InputBusField(BaseEnumField):
     AUTO_TYPE = InputBus()
 
 
+class MaxPhysAddrModeField(BaseEnumField):
+    AUTO_TYPE = MaxPhyAddrMode()
+
+
 class MigrationTypeField(BaseEnumField):
     AUTO_TYPE = MigrationType()
 
@@ -1265,6 +1317,14 @@ class RNGModelField(BaseEnumField):
     AUTO_TYPE = RNGModel()
 
 
+class ShareMappingStatusField(BaseEnumField):
+    AUTO_TYPE = ShareMappingStatus()
+
+
+class ShareMappingProtoField(BaseEnumField):
+    AUTO_TYPE = ShareMappingProto()
+
+
 class TPMModelField(BaseEnumField):
     AUTO_TYPE = TPMModel()
 
@@ -1289,6 +1349,10 @@ class VIFModelField(BaseEnumField):
     AUTO_TYPE = VIFModel()
 
 
+class VIOMMUModelField(BaseEnumField):
+    AUTO_TYPE = VIOMMUModel()
+
+
 class VMModeField(BaseEnumField):
     AUTO_TYPE = VMMode()
 
@@ -1353,6 +1417,14 @@ class InstancePowerStateField(BaseEnumField):
     AUTO_TYPE = InstancePowerState()
 
 
+class NetworkModelField(AutoTypedField):
+    AUTO_TYPE = NetworkModel()
+
+
+class NetworkVIFModelField(AutoTypedField):
+    AUTO_TYPE = NetworkVIFModel()
+
+
 class ListOfListsOfStringsField(AutoTypedField):
     AUTO_TYPE = List(List(fields.String()))
 
