@@ -26,7 +26,6 @@ from oslo_log import log as logging
 from oslo_utils import units
 from oslo_utils import uuidutils
 
-from nova.i18n import _
 import nova.privsep
 
 
@@ -113,13 +112,6 @@ def ploop_restore_descriptor(image_dir, base_delta, fmt):
                          check_exit_code=True)
 
 
-@nova.privsep.sys_admin_pctxt.entrypoint
-def enable_hairpin(interface):
-    """Enable hairpin mode for a libvirt guest."""
-    with open('/sys/class/net/%s/brport/hairpin_mode' % interface, 'w') as f:
-        f.write('1')
-
-
 @nova.privsep.sys_admin_pctxt.entrypoint
 def plug_infiniband_vif(vnic_mac, device_id, fabric, net_model, pci_slot):
     processutils.execute('ebrctl', 'add-port', vnic_mac, device_id,
@@ -174,7 +166,7 @@ def readpty(path):
 
             return f.read()
 
-    except Exception as e:
+    except Exception as exc:
         # NOTE(mikal): dear internet, I see you looking at me with your
         # judging eyes. There's a story behind why we do this. You see, the
         # previous implementation did this:
@@ -193,16 +185,12 @@ def readpty(path):
         #
         # Therefore for now we log the errors, but keep on rolling. Volunteers
         # to help clean this up are welcome and will receive free beverages.
-        LOG.info(_('Ignored error while reading from instance console '
-                   'pty: %s'), e)
+        LOG.info(
+            'Ignored error while reading from instance console pty: %s', exc
+        )
         return ''
 
 
-@nova.privsep.sys_admin_pctxt.entrypoint
-def xend_probe():
-    processutils.execute('xend', 'status', check_exit_code=True)
-
-
 @nova.privsep.sys_admin_pctxt.entrypoint
 def create_mdev(physical_device, mdev_type, uuid=None):
     """Instantiate a mediated device."""
