@@ -69,8 +69,8 @@ class ImagePropertiesFilter(filters.BaseHostFilter):
         # advertised by the host.
         if not supp_instances:
             LOG.debug("Instance contains properties %(image_props)s, "
-                        "but no corresponding supported_instances are "
-                        "advertised by the compute node",
+                      "but no corresponding supported_instances are "
+                      "advertised by the compute node",
                       {'image_props': image_props})
             return False
 
@@ -82,22 +82,34 @@ class ImagePropertiesFilter(filters.BaseHostFilter):
 
         def _compare_product_version(hyper_version, image_props):
             version_required = image_props.get('img_hv_requested_version')
-            if not(hypervisor_version and version_required):
+            if not (hypervisor_version and version_required):
                 return True
             img_prop_predicate = versionpredicate.VersionPredicate(
                 'image_prop (%s)' % version_required)
             hyper_ver_str = versionutils.convert_version_to_str(hyper_version)
             return img_prop_predicate.satisfied_by(hyper_ver_str)
 
+        def _compare_maxphysaddr_bits(host_state, image_props):
+            bits_required = image_props.get('hw_maxphysaddr_bits')
+            if not bits_required:
+                return True
+
+            bits = host_state.cpu_info.get('maxphysaddr', {}).get('bits')
+            if not bits:
+                return True
+
+            return bits >= bits_required
+
         for supp_inst in supp_instances:
             if _compare_props(checked_img_props, supp_inst):
                 if _compare_product_version(hypervisor_version, image_props):
-                    return True
+                    if _compare_maxphysaddr_bits(host_state, image_props):
+                        return True
 
         LOG.debug("Instance contains properties %(image_props)s "
-                    "that are not provided by the compute node "
-                    "supported_instances %(supp_instances)s or "
-                    "hypervisor version %(hypervisor_version)s do not match",
+                  "that are not provided by the compute node "
+                  "supported_instances %(supp_instances)s or "
+                  "hypervisor version %(hypervisor_version)s do not match",
                   {'image_props': image_props,
                    'supp_instances': supp_instances,
                    'hypervisor_version': hypervisor_version})
@@ -114,6 +126,6 @@ class ImagePropertiesFilter(filters.BaseHostFilter):
         if not self._instance_supported(host_state, image_props,
                                         host_state.hypervisor_version):
             LOG.debug("%(host_state)s does not support requested "
-                        "instance_properties", {'host_state': host_state})
+                      "instance_properties", {'host_state': host_state})
             return False
         return True
