@@ -13,8 +13,14 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
+from unittest import mock
+
+from nova.compute import api as compute
+from nova import exception
 from nova.tests.functional.api_sample_tests import test_servers
 
+HTTP_RE = r'(https?://)([\w\d:#@%/;$()~_?\+-=\\.&](#!)?)*'
+
 
 class ConsolesSampleJsonTests(test_servers.ServersSampleBase):
     microversion = None
@@ -25,7 +31,6 @@ class ConsolesSampleJsonTests(test_servers.ServersSampleBase):
         self.api.microversion = self.microversion
         self.flags(enabled=True, group='vnc')
         self.flags(enabled=True, group='spice')
-        self.flags(enabled=True, group='rdp')
         self.flags(enabled=True, group='serial_console')
 
     def test_get_vnc_console(self):
@@ -33,38 +38,47 @@ class ConsolesSampleJsonTests(test_servers.ServersSampleBase):
         response = self._do_post('servers/%s/action' % uuid,
                                  'get-vnc-console-post-req',
                                 {'action': 'os-getVNCConsole'})
-        subs = {"url":
-            "((https?):((//)|(\\\\))+([\\w\\d:#@%/;$()~_?\\+-=\\\\.&](#!)?)*)"}
-        self._verify_response('get-vnc-console-post-resp', subs, response, 200)
+        self._verify_response('get-vnc-console-post-resp', {'url': HTTP_RE},
+                              response, 200)
+
+    @mock.patch.object(compute.API, 'get_vnc_console')
+    def test_get_vnc_console_instance_invalid_state(self,
+                                                    mock_get_vnc_console):
+        uuid = self._post_server()
+
+        def fake_get_vnc_console(*args, **kwargs):
+            raise exception.InstanceInvalidState(
+                attr='fake_attr', state='fake_state', method='fake_method',
+                instance_uuid=uuid)
+
+        mock_get_vnc_console.side_effect = fake_get_vnc_console
+        response = self._do_post('servers/%s/action' % uuid,
+                                 'get-vnc-console-post-req',
+                                 {'action': 'os-getVNCConsole'})
+        self.assertEqual(409, response.status_code)
 
     def test_get_spice_console(self):
         uuid = self._post_server()
         response = self._do_post('servers/%s/action' % uuid,
                                  'get-spice-console-post-req',
                                 {'action': 'os-getSPICEConsole'})
-        subs = {"url":
-            "((https?):((//)|(\\\\))+([\\w\\d:#@%/;$()~_?\\+-=\\\\.&](#!)?)*)"}
-        self._verify_response('get-spice-console-post-resp', subs,
+        self._verify_response('get-spice-console-post-resp', {'url': HTTP_RE},
                               response, 200)
 
-    def test_get_rdp_console(self):
+    def test_get_rdp_console_bad_request(self):
+        """Ensure http 400 error is return from RDP console request"""
         uuid = self._post_server()
         response = self._do_post('servers/%s/action' % uuid,
                                  'get-rdp-console-post-req',
                                 {'action': 'os-getRDPConsole'})
-        subs = {"url":
-            "((https?):((//)|(\\\\))+([\\w\\d:#@%/;$()~_?\\+-=\\\\.&](#!)?)*)"}
-        self._verify_response('get-rdp-console-post-resp', subs,
-                              response, 200)
+        self.assertEqual(400, response.status_code)
 
     def test_get_serial_console(self):
         uuid = self._post_server()
         response = self._do_post('servers/%s/action' % uuid,
                                  'get-serial-console-post-req',
                                 {'action': 'os-getSerialConsole'})
-        subs = {"url":
-            "((https?):((//)|(\\\\))+([\\w\\d:#@%/;$()~_?\\+-=\\\\.&](#!)?)*)"}
-        self._verify_response('get-serial-console-post-resp', subs,
+        self._verify_response('get-serial-console-post-resp', {'url': HTTP_RE},
                               response, 200)
 
 
@@ -76,18 +90,22 @@ class ConsolesV26SampleJsonTests(test_servers.ServersSampleBase):
     # by appending '(v2_6)' in test_id.
     scenarios = [('v2_6', {'api_major_version': 'v2.1'})]
 
-    def setUp(self):
-        super(ConsolesV26SampleJsonTests, self).setUp()
-        self.http_regex = '(https?://)([\\w\\d:#@%/;$()~_?\\+-=\\\\.&](#!)?)*'
-
     def test_create_console(self):
         uuid = self._post_server()
 
         body = {'protocol': 'vnc', 'type': 'novnc'}
         response = self._do_post('servers/%s/remote-consoles' % uuid,
                                  'create-vnc-console-req', body)
-        subs = {"url": self.http_regex}
-        self._verify_response('create-vnc-console-resp', subs, response, 200)
+        self._verify_response('create-vnc-console-resp', {'url': HTTP_RE},
+                              response, 200)
+
+    def test_create_rdp_console_bad_request(self):
+        """Ensure http 400 error is return from RDP console request"""
+        uuid = self._post_server()
+        body = {'protocol': 'rdp', 'type': 'rdp-html5'}
+        response = self._do_post('servers/%s/remote-consoles' % uuid,
+                                 'create-rdp-console-req', body)
+        self.assertEqual(400, response.status_code)
 
 
 class ConsolesV28SampleJsonTests(test_servers.ServersSampleBase):
@@ -97,7 +115,6 @@ class ConsolesV28SampleJsonTests(test_servers.ServersSampleBase):
 
     def setUp(self):
         super(ConsolesV28SampleJsonTests, self).setUp()
-        self.http_regex = '(https?://)([\\w\\d:#@%/;$()~_?\\+-=\\\\.&](#!)?)*'
         self.flags(enabled=True, group='mks')
 
     def test_create_mks_console(self):
@@ -106,5 +123,5 @@ class ConsolesV28SampleJsonTests(test_servers.ServersSampleBase):
         body = {'protocol': 'mks', 'type': 'webmks'}
         response = self._do_post('servers/%s/remote-consoles' % uuid,
                                  'create-mks-console-req', body)
-        subs = {"url": self.http_regex}
-        self._verify_response('create-mks-console-resp', subs, response, 200)
+        self._verify_response('create-mks-console-resp', {'url': HTTP_RE},
+                              response, 200)
