@@ -14,7 +14,6 @@
 #    under the License.
 
 from oslo_serialization import jsonutils
-import six
 
 from nova import objects
 from nova import test
@@ -120,7 +119,7 @@ class ExtendedIpsTestV21(test.TestCase):
         return jsonutils.loads(body).get('servers')
 
     def _get_ips(self, server):
-        for network in six.itervalues(server['addresses']):
+        for network in server['addresses'].values():
             for ip in network:
                 yield ip
 
@@ -133,14 +132,14 @@ class ExtendedIpsTestV21(test.TestCase):
         self.assertJsonEqual(ALL_IPS, results)
 
     def test_show(self):
-        url = '/v2/fake/servers/%s' % UUID3
+        url = '/v2/%s/servers/%s' % (fakes.FAKE_PROJECT_ID, UUID3)
         res = self._make_request(url)
 
         self.assertEqual(res.status_int, 200)
         self.assertServerStates(self._get_server(res.body))
 
     def test_detail(self):
-        url = '/v2/fake/servers/detail'
+        url = '/v2/%s/servers/detail' % fakes.FAKE_PROJECT_ID
         res = self._make_request(url)
 
         self.assertEqual(res.status_int, 200)
