@@ -14,13 +14,12 @@
 #    under the License.
 
 import copy
+from unittest import mock
 
-import mock
 from oslo_serialization import jsonutils
 import webob
 
 from nova.api.openstack.compute import image_metadata as image_metadata_v21
-from nova.api.openstack.compute.legacy_v2 import image_metadata
 from nova import exception
 from nova import test
 from nova.tests.unit.api.openstack import fakes
@@ -37,49 +36,50 @@ def get_image_123():
 class ImageMetaDataTestV21(test.NoDBTestCase):
     controller_class = image_metadata_v21.ImageMetadataController
     invalid_request = exception.ValidationError
+    base_path = '/v2/%s/images/' % fakes.FAKE_PROJECT_ID
 
     def setUp(self):
         super(ImageMetaDataTestV21, self).setUp()
         self.controller = self.controller_class()
 
-    @mock.patch('nova.image.api.API.get', return_value=get_image_123())
+    @mock.patch('nova.image.glance.API.get', return_value=get_image_123())
     def test_index(self, get_all_mocked):
-        req = fakes.HTTPRequest.blank('/v2/fake/images/123/metadata')
+        req = fakes.HTTPRequest.blank(self.base_path + '123/metadata')
         res_dict = self.controller.index(req, '123')
         expected = {'metadata': {'key1': 'value1'}}
         self.assertEqual(res_dict, expected)
         get_all_mocked.assert_called_once_with(mock.ANY, '123')
 
-    @mock.patch('nova.image.api.API.get', return_value=get_image_123())
+    @mock.patch('nova.image.glance.API.get', return_value=get_image_123())
     def test_show(self, get_mocked):
-        req = fakes.HTTPRequest.blank('/v2/fake/images/123/metadata/key1')
+        req = fakes.HTTPRequest.blank(self.base_path + '123/metadata/key1')
         res_dict = self.controller.show(req, '123', 'key1')
         self.assertIn('meta', res_dict)
         self.assertEqual(len(res_dict['meta']), 1)
         self.assertEqual('value1', res_dict['meta']['key1'])
         get_mocked.assert_called_once_with(mock.ANY, '123')
 
-    @mock.patch('nova.image.api.API.get', return_value=get_image_123())
+    @mock.patch('nova.image.glance.API.get', return_value=get_image_123())
     def test_show_not_found(self, _get_mocked):
-        req = fakes.HTTPRequest.blank('/v2/fake/images/123/metadata/key9')
+        req = fakes.HTTPRequest.blank(self.base_path + '123/metadata/key9')
         self.assertRaises(webob.exc.HTTPNotFound,
                           self.controller.show, req, '123', 'key9')
 
-    @mock.patch('nova.image.api.API.get',
+    @mock.patch('nova.image.glance.API.get',
                 side_effect=exception.ImageNotFound(image_id='100'))
     def test_show_image_not_found(self, _get_mocked):
-        req = fakes.HTTPRequest.blank('/v2/fake/images/100/metadata/key1')
+        req = fakes.HTTPRequest.blank(self.base_path + '100/metadata/key1')
         self.assertRaises(webob.exc.HTTPNotFound,
                           self.controller.show, req, '100', 'key9')
 
     @mock.patch(CHK_QUOTA_STR)
-    @mock.patch('nova.image.api.API.update')
-    @mock.patch('nova.image.api.API.get', return_value=get_image_123())
+    @mock.patch('nova.image.glance.API.update')
+    @mock.patch('nova.image.glance.API.get', return_value=get_image_123())
     def test_create(self, get_mocked, update_mocked, quota_mocked):
         mock_result = copy.deepcopy(get_image_123())
         mock_result['properties']['key7'] = 'value7'
         update_mocked.return_value = mock_result
-        req = fakes.HTTPRequest.blank('/v2/fake/images/123/metadata')
+        req = fakes.HTTPRequest.blank(self.base_path + '123/metadata')
         req.method = 'POST'
         body = {"metadata": {"key7": "value7"}}
         req.body = jsonutils.dump_as_bytes(body)
@@ -99,12 +99,12 @@ class ImageMetaDataTestV21(test.NoDBTestCase):
         self.assertEqual(expected_output, res)
 
     @mock.patch(CHK_QUOTA_STR)
-    @mock.patch('nova.image.api.API.update')
-    @mock.patch('nova.image.api.API.get',
+    @mock.patch('nova.image.glance.API.update')
+    @mock.patch('nova.image.glance.API.get',
                 side_effect=exception.ImageNotFound(image_id='100'))
     def test_create_image_not_found(self, _get_mocked, update_mocked,
                                     quota_mocked):
-        req = fakes.HTTPRequest.blank('/v2/fake/images/100/metadata')
+        req = fakes.HTTPRequest.blank(self.base_path + '100/metadata')
         req.method = 'POST'
         body = {"metadata": {"key7": "value7"}}
         req.body = jsonutils.dump_as_bytes(body)
@@ -116,10 +116,10 @@ class ImageMetaDataTestV21(test.NoDBTestCase):
         self.assertFalse(update_mocked.called)
 
     @mock.patch(CHK_QUOTA_STR)
-    @mock.patch('nova.image.api.API.update')
-    @mock.patch('nova.image.api.API.get', return_value=get_image_123())
+    @mock.patch('nova.image.glance.API.update')
+    @mock.patch('nova.image.glance.API.get', return_value=get_image_123())
     def test_update_all(self, get_mocked, update_mocked, quota_mocked):
-        req = fakes.HTTPRequest.blank('/v2/fake/images/123/metadata')
+        req = fakes.HTTPRequest.blank(self.base_path + '123/metadata')
         req.method = 'PUT'
         body = {"metadata": {"key9": "value9"}}
         req.body = jsonutils.dump_as_bytes(body)
@@ -138,10 +138,10 @@ class ImageMetaDataTestV21(test.NoDBTestCase):
         self.assertEqual(expected_output, res)
 
     @mock.patch(CHK_QUOTA_STR)
-    @mock.patch('nova.image.api.API.get',
+    @mock.patch('nova.image.glance.API.get',
                 side_effect=exception.ImageNotFound(image_id='100'))
     def test_update_all_image_not_found(self, _get_mocked, quota_mocked):
-        req = fakes.HTTPRequest.blank('/v2/fake/images/100/metadata')
+        req = fakes.HTTPRequest.blank(self.base_path + '100/metadata')
         req.method = 'PUT'
         body = {"metadata": {"key9": "value9"}}
         req.body = jsonutils.dump_as_bytes(body)
@@ -152,10 +152,10 @@ class ImageMetaDataTestV21(test.NoDBTestCase):
         self.assertFalse(quota_mocked.called)
 
     @mock.patch(CHK_QUOTA_STR)
-    @mock.patch('nova.image.api.API.update')
-    @mock.patch('nova.image.api.API.get', return_value=get_image_123())
+    @mock.patch('nova.image.glance.API.update')
+    @mock.patch('nova.image.glance.API.get', return_value=get_image_123())
     def test_update_item(self, _get_mocked, update_mocked, quota_mocked):
-        req = fakes.HTTPRequest.blank('/v2/fake/images/123/metadata/key1')
+        req = fakes.HTTPRequest.blank(self.base_path + '123/metadata/key1')
         req.method = 'PUT'
         body = {"meta": {"key1": "zz"}}
         req.body = jsonutils.dump_as_bytes(body)
@@ -173,10 +173,10 @@ class ImageMetaDataTestV21(test.NoDBTestCase):
         self.assertEqual(res, expected_output)
 
     @mock.patch(CHK_QUOTA_STR)
-    @mock.patch('nova.image.api.API.get',
+    @mock.patch('nova.image.glance.API.get',
                 side_effect=exception.ImageNotFound(image_id='100'))
     def test_update_item_image_not_found(self, _get_mocked, quota_mocked):
-        req = fakes.HTTPRequest.blank('/v2/fake/images/100/metadata/key1')
+        req = fakes.HTTPRequest.blank(self.base_path + '100/metadata/key1')
         req.method = 'PUT'
         body = {"meta": {"key1": "zz"}}
         req.body = jsonutils.dump_as_bytes(body)
@@ -188,11 +188,11 @@ class ImageMetaDataTestV21(test.NoDBTestCase):
         self.assertFalse(quota_mocked.called)
 
     @mock.patch(CHK_QUOTA_STR)
-    @mock.patch('nova.image.api.API.update')
-    @mock.patch('nova.image.api.API.get')
+    @mock.patch('nova.image.glance.API.update')
+    @mock.patch('nova.image.glance.API.get')
     def test_update_item_bad_body(self, get_mocked, update_mocked,
                                   quota_mocked):
-        req = fakes.HTTPRequest.blank('/v2/fake/images/123/metadata/key1')
+        req = fakes.HTTPRequest.blank(self.base_path + '123/metadata/key1')
         req.method = 'PUT'
         body = {"key1": "zz"}
         req.body = b''
@@ -207,11 +207,11 @@ class ImageMetaDataTestV21(test.NoDBTestCase):
 
     @mock.patch(CHK_QUOTA_STR,
                 side_effect=webob.exc.HTTPBadRequest())
-    @mock.patch('nova.image.api.API.update')
-    @mock.patch('nova.image.api.API.get')
+    @mock.patch('nova.image.glance.API.update')
+    @mock.patch('nova.image.glance.API.get')
     def test_update_item_too_many_keys(self, get_mocked, update_mocked,
                                        _quota_mocked):
-        req = fakes.HTTPRequest.blank('/v2/fake/images/123/metadata/key1')
+        req = fakes.HTTPRequest.blank(self.base_path + '123/metadata/key1')
         req.method = 'PUT'
         body = {"meta": {"foo": "bar"}}
         req.body = jsonutils.dump_as_bytes(body)
@@ -224,11 +224,11 @@ class ImageMetaDataTestV21(test.NoDBTestCase):
         self.assertFalse(update_mocked.called)
 
     @mock.patch(CHK_QUOTA_STR)
-    @mock.patch('nova.image.api.API.update')
-    @mock.patch('nova.image.api.API.get', return_value=get_image_123())
+    @mock.patch('nova.image.glance.API.update')
+    @mock.patch('nova.image.glance.API.get', return_value=get_image_123())
     def test_update_item_body_uri_mismatch(self, _get_mocked, update_mocked,
                                            quota_mocked):
-        req = fakes.HTTPRequest.blank('/v2/fake/images/123/metadata/bad')
+        req = fakes.HTTPRequest.blank(self.base_path + '123/metadata/bad')
         req.method = 'PUT'
         body = {"meta": {"key1": "value1"}}
         req.body = jsonutils.dump_as_bytes(body)
@@ -240,10 +240,10 @@ class ImageMetaDataTestV21(test.NoDBTestCase):
         self.assertFalse(quota_mocked.called)
         self.assertFalse(update_mocked.called)
 
-    @mock.patch('nova.image.api.API.update')
-    @mock.patch('nova.image.api.API.get', return_value=get_image_123())
+    @mock.patch('nova.image.glance.API.update')
+    @mock.patch('nova.image.glance.API.get', return_value=get_image_123())
     def test_delete(self, _get_mocked, update_mocked):
-        req = fakes.HTTPRequest.blank('/v2/fake/images/123/metadata/key1')
+        req = fakes.HTTPRequest.blank(self.base_path + '123/metadata/key1')
         req.method = 'DELETE'
         res = self.controller.delete(req, '123', 'key1')
         expected = copy.deepcopy(get_image_123())
@@ -253,18 +253,18 @@ class ImageMetaDataTestV21(test.NoDBTestCase):
 
         self.assertIsNone(res)
 
-    @mock.patch('nova.image.api.API.get', return_value=get_image_123())
+    @mock.patch('nova.image.glance.API.get', return_value=get_image_123())
     def test_delete_not_found(self, _get_mocked):
-        req = fakes.HTTPRequest.blank('/v2/fake/images/123/metadata/blah')
+        req = fakes.HTTPRequest.blank(self.base_path + '123/metadata/blah')
         req.method = 'DELETE'
 
         self.assertRaises(webob.exc.HTTPNotFound,
                           self.controller.delete, req, '123', 'blah')
 
-    @mock.patch('nova.image.api.API.get',
+    @mock.patch('nova.image.glance.API.get',
                 side_effect=exception.ImageNotFound(image_id='100'))
     def test_delete_image_not_found(self, _get_mocked):
-        req = fakes.HTTPRequest.blank('/v2/fake/images/100/metadata/key1')
+        req = fakes.HTTPRequest.blank(self.base_path + '100/metadata/key1')
         req.method = 'DELETE'
 
         self.assertRaises(webob.exc.HTTPNotFound,
@@ -272,12 +272,12 @@ class ImageMetaDataTestV21(test.NoDBTestCase):
 
     @mock.patch(CHK_QUOTA_STR,
                 side_effect=webob.exc.HTTPForbidden(explanation=''))
-    @mock.patch('nova.image.api.API.update')
-    @mock.patch('nova.image.api.API.get', return_value=get_image_123())
+    @mock.patch('nova.image.glance.API.update')
+    @mock.patch('nova.image.glance.API.get', return_value=get_image_123())
     def test_too_many_metadata_items_on_create(self, _get_mocked,
                                                update_mocked, _quota_mocked):
         body = {"metadata": {"foo": "bar"}}
-        req = fakes.HTTPRequest.blank('/v2/fake/images/123/metadata')
+        req = fakes.HTTPRequest.blank(self.base_path + '123/metadata')
         req.method = 'POST'
         req.body = jsonutils.dump_as_bytes(body)
         req.headers["content-type"] = "application/json"
@@ -288,11 +288,11 @@ class ImageMetaDataTestV21(test.NoDBTestCase):
 
     @mock.patch(CHK_QUOTA_STR,
                 side_effect=webob.exc.HTTPForbidden(explanation=''))
-    @mock.patch('nova.image.api.API.update')
-    @mock.patch('nova.image.api.API.get', return_value=get_image_123())
+    @mock.patch('nova.image.glance.API.update')
+    @mock.patch('nova.image.glance.API.get', return_value=get_image_123())
     def test_too_many_metadata_items_on_put(self, _get_mocked,
                                             update_mocked, _quota_mocked):
-        req = fakes.HTTPRequest.blank('/v2/fake/images/123/metadata/blah')
+        req = fakes.HTTPRequest.blank(self.base_path + '123/metadata/blah')
         req.method = 'PUT'
         body = {"meta": {"blah": "blah", "blah1": "blah1"}}
         req.body = jsonutils.dump_as_bytes(body)
@@ -303,10 +303,10 @@ class ImageMetaDataTestV21(test.NoDBTestCase):
                           body=body)
         self.assertFalse(update_mocked.called)
 
-    @mock.patch('nova.image.api.API.get',
+    @mock.patch('nova.image.glance.API.get',
                 side_effect=exception.ImageNotAuthorized(image_id='123'))
     def test_image_not_authorized_update(self, _get_mocked):
-        req = fakes.HTTPRequest.blank('/v2/fake/images/123/metadata/key1')
+        req = fakes.HTTPRequest.blank(self.base_path + '123/metadata/key1')
         req.method = 'PUT'
         body = {"meta": {"key1": "value1"}}
         req.body = jsonutils.dump_as_bytes(body)
@@ -316,14 +316,14 @@ class ImageMetaDataTestV21(test.NoDBTestCase):
                           self.controller.update, req, '123', 'key1',
                           body=body)
 
-    @mock.patch('nova.image.api.API.get',
+    @mock.patch('nova.image.glance.API.get',
                 side_effect=exception.ImageNotAuthorized(image_id='123'))
     def test_image_not_authorized_update_all(self, _get_mocked):
         image_id = 131
         # see nova.tests.unit.api.openstack.fakes:_make_image_fixtures
 
-        req = fakes.HTTPRequest.blank('/v2/fake/images/%s/metadata/key1'
-                                      % image_id)
+        req = fakes.HTTPRequest.blank(self.base_path +
+                                      '%s/metadata/key1' % image_id)
         req.method = 'PUT'
         body = {"metadata": {"key1": "value1"}}
         req.body = jsonutils.dump_as_bytes(body)
@@ -333,14 +333,14 @@ class ImageMetaDataTestV21(test.NoDBTestCase):
                           self.controller.update_all, req, image_id,
                           body=body)
 
-    @mock.patch('nova.image.api.API.get',
+    @mock.patch('nova.image.glance.API.get',
                 side_effect=exception.ImageNotAuthorized(image_id='123'))
     def test_image_not_authorized_create(self, _get_mocked):
         image_id = 131
         # see nova.tests.unit.api.openstack.fakes:_make_image_fixtures
 
-        req = fakes.HTTPRequest.blank('/v2/fake/images/%s/metadata/key1'
-                                      % image_id)
+        req = fakes.HTTPRequest.blank(self.base_path +
+                                      '%s/metadata/key1' % image_id)
         req.method = 'POST'
         body = {"metadata": {"key1": "value1"}}
         req.body = jsonutils.dump_as_bytes(body)
@@ -351,21 +351,26 @@ class ImageMetaDataTestV21(test.NoDBTestCase):
                           body=body)
 
 
-class ImageMetaDataTestV2(ImageMetaDataTestV21):
-    controller_class = image_metadata.Controller
-    invalid_request = webob.exc.HTTPBadRequest
+class ImageMetadataControllerV239(test.NoDBTestCase):
 
-    # NOTE(cyeoh): This duplicate unittest is necessary for a race condition
-    # with the V21 unittests. It's mock issue.
-    @mock.patch('nova.image.api.API.update')
-    @mock.patch('nova.image.api.API.get', return_value=get_image_123())
-    def test_delete(self, _get_mocked, update_mocked):
-        req = fakes.HTTPRequest.blank('/v2/fake/images/123/metadata/key1')
-        req.method = 'DELETE'
-        res = self.controller.delete(req, '123', 'key1')
-        expected = copy.deepcopy(get_image_123())
-        expected['properties'] = {}
-        update_mocked.assert_called_once_with(mock.ANY, '123', expected,
-                                             data=None, purge_props=True)
+    def setUp(self):
+        super(ImageMetadataControllerV239, self).setUp()
+        self.controller = image_metadata_v21.ImageMetadataController()
+        self.req = fakes.HTTPRequest.blank('', version='2.39')
 
-        self.assertIsNone(res)
+    def test_not_found_for_all_image_metadata_api(self):
+        self.assertRaises(exception.VersionNotFoundForAPIMethod,
+                          self.controller.index, self.req)
+        self.assertRaises(exception.VersionNotFoundForAPIMethod,
+                          self.controller.show, self.req, fakes.FAKE_UUID)
+        self.assertRaises(exception.VersionNotFoundForAPIMethod,
+                          self.controller.create, self.req,
+                          fakes.FAKE_UUID, {'metadata': {}})
+        self.assertRaises(exception.VersionNotFoundForAPIMethod,
+                          self.controller.update, self.req,
+                          fakes.FAKE_UUID, 'id', {'metadata': {}})
+        self.assertRaises(exception.VersionNotFoundForAPIMethod,
+                          self.controller.update_all, self.req,
+                          fakes.FAKE_UUID, {'metadata': {}})
+        self.assertRaises(exception.VersionNotFoundForAPIMethod,
+                          self.controller.delete, self.req, fakes.FAKE_UUID)
