@@ -13,11 +13,11 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
+from oslo_utils.fixture import uuidsentinel as uuids
 from oslo_utils import timeutils
 
 from nova import block_device
 from nova import objects
-from nova.tests import uuidsentinel as uuids
 
 
 def fake_bdm_object(context, bdm_dict):
