@@ -14,6 +14,8 @@
 
 import datetime
 
+from oslo_utils.fixture import uuidsentinel as uuids
+
 from nova import exception
 from nova import objects
 from nova.objects import fields
@@ -108,6 +110,7 @@ class TestImageMetaProps(test.NoDBTestCase):
                  'hw_video_model': 'vga',
                  'hw_video_ram': '512',
                  'hw_qemu_guest_agent': 'yes',
+                 'hw_locked_memory': 'true',
                  'trait:CUSTOM_TRUSTED': 'required',
                  # Fill sane values for the rest here
                  }
@@ -116,6 +119,7 @@ class TestImageMetaProps(test.NoDBTestCase):
         self.assertEqual('vga', virtprops.hw_video_model)
         self.assertEqual(512, virtprops.hw_video_ram)
         self.assertTrue(virtprops.hw_qemu_guest_agent)
+        self.assertTrue(virtprops.hw_locked_memory)
         self.assertIsNotNone(virtprops.traits_required)
         self.assertIn('CUSTOM_TRUSTED', virtprops.traits_required)
 
@@ -285,6 +289,28 @@ class TestImageMetaProps(test.NoDBTestCase):
         self.assertEqual([set([0, 1, 2, 3])],
                          virtprops.hw_numa_cpus)
 
+    def test_locked_memory_prop(self):
+        props = {'hw_locked_memory': 'true'}
+        virtprops = objects.ImageMetaProps.from_dict(props)
+        self.assertTrue(virtprops.hw_locked_memory)
+
+    def test_obj_make_compatible_hw_locked_memory(self):
+        """Check 'hw_locked_memory' compatibility."""
+        # assert that 'hw_locked_memory' is supported
+        # on a suitably new version
+        obj = objects.ImageMetaProps(
+            hw_locked_memory='true',
+        )
+        primitive = obj.obj_to_primitive('1.33')
+        self.assertIn('hw_locked_memory',
+            primitive['nova_object.data'])
+        self.assertTrue(primitive['nova_object.data']['hw_locked_memory'])
+
+        # and is absent on older versions
+        primitive = obj.obj_to_primitive('1.32')
+        self.assertNotIn('hw_locked_memory',
+                         primitive['nova_object.data'])
+
     def test_get_unnumbered_trait_fields(self):
         """Tests that only valid un-numbered required traits are parsed from
         the properties.
@@ -334,6 +360,8 @@ class TestImageMetaProps(test.NoDBTestCase):
             'img_hv_requested_version': '>= 1.0',
             'os_require_quiesce': True,
             'os_secure_boot': 'required',
+            'hw_maxphysaddr_mode': 'passthrough',
+            'hw_maxphysaddr_bits': 42,
             'hw_rescue_bus': 'ide',
             'hw_rescue_device': 'disk',
             'hw_watchdog_action': fields.WatchdogAction.DISABLED,
@@ -349,6 +377,34 @@ class TestImageMetaProps(test.NoDBTestCase):
             self.assertRaises(exception.ObjectActionError,
                               obj.obj_to_primitive, '1.0')
 
+    def test_obj_make_compatible_hw_ephemeral_encryption(self):
+        """Check 'hw_ephemeral_encryption(_format)' compatibility."""
+        # assert that 'hw_ephemeral_encryption' and
+        # 'hw_ephemeral_encryption_format' is supported
+        # on a suitably new version
+        new_fields = (
+            'hw_ephemeral_encryption',
+            'hw_ephemeral_encryption_format'
+        )
+        eph_format = objects.fields.BlockDeviceEncryptionFormatType.LUKS
+        obj = objects.ImageMetaProps(
+            hw_ephemeral_encryption='yes',
+            hw_ephemeral_encryption_format=eph_format,
+        )
+        primitive = obj.obj_to_primitive('1.32')
+        for field in new_fields:
+            self.assertIn(field, primitive['nova_object.data'])
+        self.assertTrue(
+            primitive['nova_object.data']['hw_ephemeral_encryption'])
+        self.assertEqual(
+            eph_format,
+            primitive['nova_object.data']['hw_ephemeral_encryption_format'])
+
+        # and is absent on older versions
+        primitive = obj.obj_to_primitive('1.31')
+        for field in new_fields:
+            self.assertNotIn(field, primitive['nova_object.data'])
+
     def test_obj_make_compatible_hw_emulation(self):
         """Check 'hw_emulation_architecture' compatibility."""
         # assert that 'hw_emulation_architecture' is supported
@@ -447,6 +503,20 @@ class TestImageMetaProps(test.NoDBTestCase):
         secure_props = objects.ImageMetaProps.from_dict(props)
         self.assertEqual("required", secure_props.os_secure_boot)
 
+    def test_set_hw_maxphysaddr_mode(self):
+        props = {'hw_maxphysaddr_mode': "passthrough"}
+        obj = objects.ImageMetaProps.from_dict(props)
+        self.assertEqual("passthrough", obj.hw_maxphysaddr_mode)
+
+    def test_set_hw_maxphysaddr_mode_negative(self):
+        props = {'hw_maxphysaddr_mode': "blah"}
+        self.assertRaises(ValueError, objects.ImageMetaProps.from_dict, props)
+
+    def test_set_hw_maxphysaddr_bits(self):
+        props = {'hw_maxphysaddr_bits': 42}
+        obj = objects.ImageMetaProps.from_dict(props)
+        self.assertEqual(42, obj.hw_maxphysaddr_bits)
+
     def test_obj_make_compatible_img_hide_hypervisor_id(self):
         """Tests that checks if we pop img_hide_hypervisor_id."""
         obj = objects.ImageMetaProps(img_hide_hypervisor_id=True)
@@ -486,3 +556,38 @@ class TestImageMetaProps(test.NoDBTestCase):
             hw_pci_numa_affinity_policy=fields.PCINUMAAffinityPolicy.SOCKET)
         self.assertRaises(exception.ObjectActionError,
                           obj.obj_to_primitive, '1.27')
+
+    def test_obj_make_compatible_viommu_model(self):
+        """Check 'hw_viommu_model' compatibility."""
+        # assert that 'hw_viommu_model' is supported on a suitably new version
+        obj = objects.ImageMetaProps(
+            hw_viommu_model=objects.fields.VIOMMUModel.VIRTIO,
+        )
+        primitive = obj.obj_to_primitive('1.34')
+        self.assertIn('hw_viommu_model', primitive['nova_object.data'])
+        self.assertEqual(
+            objects.fields.VIOMMUModel.VIRTIO,
+            primitive['nova_object.data']['hw_viommu_model'])
+
+        # and is absent on older versions
+        primitive = obj.obj_to_primitive('1.33')
+        self.assertNotIn('hw_viommu_model', primitive['nova_object.data'])
+
+    def test_obj_make_compatible_ephemeral_encryption_secret_uuid(self):
+        """Check 'hw_ephemeral_encryption_secret_uuid' compatibility."""
+        obj = objects.ImageMetaProps(
+            hw_ephemeral_encryption_secret_uuid=uuids.secret)
+
+        primitive = obj.obj_to_primitive('1.37')
+        self.assertIn(
+            'hw_ephemeral_encryption_secret_uuid',
+            primitive['nova_object.data'])
+        self.assertEqual(
+            uuids.secret,
+            primitive[
+                'nova_object.data']['hw_ephemeral_encryption_secret_uuid'])
+
+        primitive = obj.obj_to_primitive('1.36')
+        self.assertNotIn(
+            'hw_ephemeral_encryption_secret_uuid',
+            primitive['nova_object.data'])
