@@ -10,8 +10,9 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
+from unittest import mock
+
 import fixtures
-import mock
 from nova.policies import base as base_policy
 from nova.policies import rescue as rs_policies
 from oslo_utils.fixture import uuidsentinel as uuids
@@ -89,7 +90,7 @@ class RescueServerPolicyTest(base.BasePolicyTest):
             exc.format_message())
 
     @mock.patch('nova.compute.api.API.rescue')
-    def test_rescue_sevrer_overridden_policy_pass_with_same_user(
+    def test_rescue_server_overridden_policy_pass_with_same_user(
         self, mock_rescue):
         rule_name = rs_policies.BASE_POLICY_NAME
         self.policy.set_rules({rule_name: "user_id:%(user_id)s"})
@@ -99,24 +100,23 @@ class RescueServerPolicyTest(base.BasePolicyTest):
 
 
 class RescueServerNoLegacyNoScopePolicyTest(RescueServerPolicyTest):
-    """Test rescue/unrescue server APIs policies with no legacy deprecated rules
-    and no scope checks which means new defaults only.
-
+    """Test rescue/unrescue server APIs policies with no legacy deprecated
+    rules and no scope checks which means new defaults only.
     """
 
     without_deprecated_rules = True
     rules_without_deprecation = {
         rs_policies.UNRESCUE_POLICY_NAME:
-            base_policy.PROJECT_MEMBER,
+            base_policy.PROJECT_MEMBER_OR_ADMIN,
         rs_policies.BASE_POLICY_NAME:
-            base_policy.PROJECT_MEMBER}
+            base_policy.PROJECT_MEMBER_OR_ADMIN}
 
     def setUp(self):
         super(RescueServerNoLegacyNoScopePolicyTest, self).setUp()
         # With no legacy rule, only project admin or member will be
         # able to rescue/unrescue the server.
-        self.project_action_authorized_contexts = [
-            self.project_admin_context, self.project_member_context]
+        self.project_action_authorized_contexts = (
+            self.project_member_or_admin_with_no_scope_no_legacy)
 
 
 class RescueServerScopeTypePolicyTest(RescueServerPolicyTest):
@@ -134,10 +134,8 @@ class RescueServerScopeTypePolicyTest(RescueServerPolicyTest):
         self.flags(enforce_scope=True, group="oslo_policy")
         # Scope enable will not allow system admin to rescue/unrescue the
         # server.
-        self.project_action_authorized_contexts = [
-            self.legacy_admin_context,
-            self.project_admin_context, self.project_member_context,
-            self.project_reader_context, self.project_foo_context]
+        self.project_action_authorized_contexts = (
+            self.project_m_r_or_admin_with_scope_and_legacy)
 
 
 class RescueServerScopeTypeNoLegacyPolicyTest(RescueServerScopeTypePolicyTest):
@@ -148,13 +146,13 @@ class RescueServerScopeTypeNoLegacyPolicyTest(RescueServerScopeTypePolicyTest):
     without_deprecated_rules = True
     rules_without_deprecation = {
         rs_policies.UNRESCUE_POLICY_NAME:
-            base_policy.PROJECT_MEMBER,
+            base_policy.PROJECT_MEMBER_OR_ADMIN,
         rs_policies.BASE_POLICY_NAME:
-            base_policy.PROJECT_MEMBER}
+            base_policy.PROJECT_MEMBER_OR_ADMIN}
 
     def setUp(self):
         super(RescueServerScopeTypeNoLegacyPolicyTest, self).setUp()
         # With scope enable and no legacy rule, only project admin/member
         # will be able to rescue/unrescue the server.
-        self.project_action_authorized_contexts = [
-            self.project_admin_context, self.project_member_context]
+        self.project_action_authorized_contexts = (
+            self.project_member_or_admin_with_scope_no_legacy)
