@@ -58,11 +58,11 @@ class HackingTestCase(test.NoDBTestCase):
 
         self.assertEqual(expect, checks.import_no_virt_driver_import_deps(
             "from nova.virt.libvirt import utils as libvirt_utils",
-            "./nova/virt/hyperv/driver.py"))
+            "./nova/virt/zvm/driver.py"))
 
         self.assertEqual(expect, checks.import_no_virt_driver_import_deps(
             "import nova.virt.libvirt.utils as libvirt_utils",
-            "./nova/virt/hyperv/driver.py"))
+            "./nova/virt/zvm/driver.py"))
 
         self.assertIsNone(checks.import_no_virt_driver_import_deps(
             "from nova.virt.libvirt import utils as libvirt_utils",
@@ -72,7 +72,7 @@ class HackingTestCase(test.NoDBTestCase):
         self.assertIsInstance(checks.import_no_virt_driver_config_deps(
             "CONF.import_opt('volume_drivers', "
             "'nova.virt.libvirt.driver', group='libvirt')",
-            "./nova/virt/hyperv/driver.py"), tuple)
+            "./nova/virt/zm/driver.py"), tuple)
 
         self.assertIsNone(checks.import_no_virt_driver_config_deps(
             "CONF.import_opt('volume_drivers', "
