@@ -17,8 +17,8 @@
 
 import copy
 import datetime
+from unittest import mock
 
-import mock
 from oslo_config import cfg
 from oslo_context import fixture as o_fixture
 from oslo_utils.fixture import uuidsentinel as uuids
@@ -79,6 +79,7 @@ class NotificationsTestCase(test.TestCase):
                                 display_name='test_instance',
                                 hostname='test_instance_hostname',
                                 node='test_instance_node',
+                                compute_id=123,
                                 system_metadata={})
         inst._context = self.context
         if params:
@@ -112,7 +113,7 @@ class NotificationsTestCase(test.TestCase):
         # test config disable of just the task state notifications
         self.flags(notify_on_state_change="vm_state", group='notifications')
 
-        # we should not get a notification on task stgate chagne now
+        # we should not get a notification on task state change now
         old = copy.copy(self.instance)
         self.instance.task_state = task_states.SPAWNING
 
