@@ -18,7 +18,6 @@ import os.path
 import tempfile
 from unittest import mock
 
-import eventlet
 import fixtures
 from keystoneauth1 import adapter as ks_adapter
 from keystoneauth1.identity import base as ks_identity
@@ -772,8 +771,8 @@ class SpawnNTestCase(test.NoDBTestCase):
 
         def fake(arg):
             pass
-
-        with mock.patch.object(eventlet, self.spawn_name, _fake_spawn):
+        pool = utils._get_default_green_pool()
+        with mock.patch.object(pool, self.spawn_name, _fake_spawn):
             getattr(utils, self.spawn_name)(fake, 'test')
         self.assertIsNone(common_context.get_current())
 
@@ -790,7 +789,8 @@ class SpawnNTestCase(test.NoDBTestCase):
         def fake(context, kwarg1=None):
             pass
 
-        with mock.patch.object(eventlet, self.spawn_name, _fake_spawn):
+        pool = utils._get_default_green_pool()
+        with mock.patch.object(pool, self.spawn_name, _fake_spawn):
             getattr(utils, self.spawn_name)(fake, ctxt, kwarg1='test')
         self.assertEqual(ctxt, common_context.get_current())
 
@@ -810,7 +810,8 @@ class SpawnNTestCase(test.NoDBTestCase):
         def fake(context, kwarg1=None):
             pass
 
-        with mock.patch.object(eventlet, self.spawn_name, _fake_spawn):
+        pool = utils._get_default_green_pool()
+        with mock.patch.object(pool, self.spawn_name, _fake_spawn):
             getattr(utils, self.spawn_name)(fake, ctxt_passed, kwarg1='test')
         self.assertEqual(ctxt, common_context.get_current())
 
