@@ -134,11 +134,6 @@ class GuestTestCase(test.NoDBTestCase):
 
     def test_delete_configuration(self):
         self.guest.delete_configuration()
-        self.domain.undefineFlags.assert_called_once_with(
-            fakelibvirt.VIR_DOMAIN_UNDEFINE_MANAGED_SAVE)
-
-    def test_delete_configuration_with_nvram(self):
-        self.guest.delete_configuration(support_uefi=True)
         self.domain.undefineFlags.assert_called_once_with(
             fakelibvirt.VIR_DOMAIN_UNDEFINE_MANAGED_SAVE |
             fakelibvirt.VIR_DOMAIN_UNDEFINE_NVRAM)
