@@ -102,6 +102,7 @@ class DriverBlockDevice(dict):
     """
 
     _fields = set()
+    _readonly_fields = set()
 
     _proxy_as_attr_inherited = set(['uuid', 'is_volume'])
     _update_on_save = {'disk_bus': None,
@@ -204,6 +205,11 @@ class DriverBlockDevice(dict):
         raise NotImplementedError()
 
     def save(self):
+        for attr_name in self._readonly_fields:
+            if self[attr_name] != getattr(self._bdm_obj, attr_name):
+                raise AttributeError(
+                    f"can't set read-only attribute: '{attr_name}'")
+
         for attr_name, key_name in self._update_on_save.items():
             lookup_name = key_name or attr_name
             if self[lookup_name] != getattr(self._bdm_obj, attr_name):
@@ -212,10 +218,26 @@ class DriverBlockDevice(dict):
 
 
 class DriverSwapBlockDevice(DriverBlockDevice):
-    _fields = set(['device_name', 'swap_size', 'disk_bus'])
-
-    _update_on_save = {'disk_bus': None,
-                       'device_name': None}
+    _fields = set([
+        'device_name',
+        'swap_size',
+        'disk_bus',
+        'encrypted',
+        'encryption_secret_uuid',
+        'encryption_format',
+        'encryption_options',
+    ])
+    _readonly_fields = set(['encrypted'])
+    _update_on_save = {
+        'disk_bus': None,
+        'device_name': None,
+        # We don't update the 'encrypted' attribute on save because we are not
+        # going to encrypt or decrypt an existing disk due to a change in the
+        # 'encrypted' attribute value.
+        'encryption_secret_uuid': None,
+        'encryption_format': None,
+        'encryption_options': None,
+    }
 
     def _transform(self):
         if not block_device.new_format_is_swap(self._bdm_obj):
@@ -223,13 +245,86 @@ class DriverSwapBlockDevice(DriverBlockDevice):
         self.update({
             'device_name': self._bdm_obj.device_name,
             'swap_size': self._bdm_obj.volume_size or 0,
-            'disk_bus': self._bdm_obj.disk_bus
+            'disk_bus': self._bdm_obj.disk_bus,
+            'encrypted': self._bdm_obj.encrypted,
+            'encryption_secret_uuid': self._bdm_obj.encryption_secret_uuid,
+            'encryption_format': self._bdm_obj.encryption_format,
+            'encryption_options': self._bdm_obj.encryption_options
+        })
+
+
+class DriverImageBlockDevice(DriverBlockDevice):
+    _valid_source = 'image'
+    _proxy_as_attr_inherited = set(['image_id'])
+    _new_only_fields = set([
+        'disk_bus',
+        'device_type',
+        'guest_format',
+        'boot_index',
+        'encrypted',
+        'encryption_secret_uuid',
+        'encryption_format',
+        'encryption_options'
+    ])
+    _fields = set([
+        'device_name',
+        'size']) | _new_only_fields
+    _readonly_fields = set(['encrypted'])
+    _legacy_fields = (
+        _fields - _new_only_fields | set(['num', 'virtual_name']))
+    _update_on_save = {
+        'disk_bus': None,
+        'device_name': None,
+        'device_type': None,
+        # We don't update the 'encrypted' attribute on save because we are not
+        # going to encrypt or decrypt an existing disk due to a change in the
+        # 'encrypted' attribute value.
+        'encryption_secret_uuid': None,
+        'encryption_format': None,
+        'encryption_options': None,
+    }
+
+    def _transform(self):
+        if (not self._bdm_obj.get('source_type') == 'image' or
+            not self._bdm_obj.get('destination_type') == 'local'):
+            raise _InvalidType
+        self.update({
+            'device_name': self._bdm_obj.device_name,
+            'size': self._bdm_obj.volume_size or 0,
+            'disk_bus': self._bdm_obj.disk_bus,
+            'device_type': self._bdm_obj.device_type,
+            'guest_format': self._bdm_obj.guest_format,
+            'image_id': self._bdm_obj.image_id,
+            'boot_index': 0,
+            'encrypted': self._bdm_obj.encrypted,
+            'encryption_secret_uuid': self._bdm_obj.encryption_secret_uuid,
+            'encryption_format': self._bdm_obj.encryption_format,
+            'encryption_options': self._bdm_obj.encryption_options
         })
 
 
 class DriverEphemeralBlockDevice(DriverBlockDevice):
-    _new_only_fields = set(['disk_bus', 'device_type', 'guest_format'])
+    _new_only_fields = set([
+        'disk_bus',
+        'device_type',
+        'guest_format',
+        'encrypted',
+        'encryption_secret_uuid',
+        'encryption_format',
+        'encryption_options'])
     _fields = set(['device_name', 'size']) | _new_only_fields
+    _readonly_fields = set(['encrypted'])
+    _update_on_save = {
+        'disk_bus': None,
+        'device_name': None,
+        'device_type': None,
+        # We don't update the 'encrypted' attribute on save because we are not
+        # going to encrypt or decrypt an existing disk due to a change in the
+        # 'encrypted' attribute value.
+        'encryption_secret_uuid': None,
+        'encryption_format': None,
+        'encryption_options': None,
+    }
 
     def _transform(self):
         if not block_device.new_format_is_ephemeral(self._bdm_obj):
@@ -239,7 +334,11 @@ class DriverEphemeralBlockDevice(DriverBlockDevice):
             'size': self._bdm_obj.volume_size or 0,
             'disk_bus': self._bdm_obj.disk_bus,
             'device_type': self._bdm_obj.device_type,
-            'guest_format': self._bdm_obj.guest_format
+            'guest_format': self._bdm_obj.guest_format,
+            'encrypted': self._bdm_obj.encrypted,
+            'encryption_secret_uuid': self._bdm_obj.encryption_secret_uuid,
+            'encryption_format': self._bdm_obj.encryption_format,
+            'encryption_options': self._bdm_obj.encryption_options
         })
 
 
@@ -802,15 +901,15 @@ def _convert_block_devices(device_type, block_device_mapping):
 convert_swap = functools.partial(_convert_block_devices,
                                  DriverSwapBlockDevice)
 
+convert_local_images = functools.partial(_convert_block_devices,
+                                         DriverImageBlockDevice)
 
 convert_ephemerals = functools.partial(_convert_block_devices,
                                       DriverEphemeralBlockDevice)
 
-
 convert_volumes = functools.partial(_convert_block_devices,
                                    DriverVolumeBlockDevice)
 
-
 convert_snapshots = functools.partial(_convert_block_devices,
                                      DriverVolSnapshotBlockDevice)
 
@@ -897,9 +996,15 @@ def get_swap(transformed_list):
         return None
 
 
-_IMPLEMENTED_CLASSES = (DriverSwapBlockDevice, DriverEphemeralBlockDevice,
-                        DriverVolumeBlockDevice, DriverVolSnapshotBlockDevice,
-                        DriverVolImageBlockDevice, DriverVolBlankBlockDevice)
+_IMPLEMENTED_CLASSES = (
+    DriverSwapBlockDevice,
+    DriverEphemeralBlockDevice,
+    DriverVolumeBlockDevice,
+    DriverVolSnapshotBlockDevice,
+    DriverVolImageBlockDevice,
+    DriverVolBlankBlockDevice,
+    DriverImageBlockDevice
+)
 
 
 def is_implemented(bdm):
@@ -912,6 +1017,10 @@ def is_implemented(bdm):
     return False
 
 
+def is_local_image(bdm):
+    return bdm.source_type == 'image' and bdm.destination_type == 'local'
+
+
 def is_block_device_mapping(bdm):
     return (bdm.source_type in ('image', 'volume', 'snapshot', 'blank') and
             bdm.destination_type == 'volume' and
