@@ -143,37 +143,50 @@ def check_vmdk_image(image_id, data):
 
 
 def do_image_deep_inspection(img, image_href, path):
+    ami_formats = ('ami', 'aki', 'ari')
     disk_format = img['disk_format']
     try:
         # NOTE(danms): Use our own cautious inspector module to make sure
         # the image file passes safety checks.
         # See https://bugs.launchpad.net/nova/+bug/2059809 for details.
-        inspector_cls = format_inspector.get_inspector(disk_format)
-        if not inspector_cls.from_file(path).safety_check():
+
+        # Make sure we have a format inspector for the claimed format, else
+        # it is something we do not support and must reject. AMI is excluded.
+        if (disk_format not in ami_formats and
+                not format_inspector.get_inspector(disk_format)):
+            raise exception.ImageUnacceptable(
+                image_id=image_href,
+                reason=_('Image not in a supported format'))
+
+        inspector = format_inspector.detect_file_format(path)
+        if not inspector.safety_check():
             raise exception.ImageUnacceptable(
                 image_id=image_href,
                 reason=(_('Image does not pass safety check')))
+
+        # AMI formats can be other things, so don't obsess over this
+        # requirement for them. Otherwise, make sure our detection agrees
+        # with glance.
+        if disk_format not in ami_formats and str(inspector) != disk_format:
+            # If we detected the image as something other than glance claimed,
+            # we abort.
+            raise exception.ImageUnacceptable(
+                image_id=image_href,
+                reason=_('Image content does not match disk_format'))
     except format_inspector.ImageFormatError:
         # If the inspector we chose based on the image's metadata does not
         # think the image is the proper format, we refuse to use it.
         raise exception.ImageUnacceptable(
             image_id=image_href,
             reason=_('Image content does not match disk_format'))
-    except AttributeError:
-        # No inspector was found
-        LOG.warning('Unable to perform deep image inspection on type %r',
-                    img['disk_format'])
-        if disk_format in ('ami', 'aki', 'ari'):
-            # A lot of things can be in a UEC, although it is typically a raw
-            # filesystem. We really have nothing we can do other than treat it
-            # like a 'raw', which is what qemu-img will detect a filesystem as
-            # anyway. If someone puts a qcow2 inside, we should fail because
-            # we won't do our inspection.
-            disk_format = 'raw'
-        else:
-            raise exception.ImageUnacceptable(
-                image_id=image_href,
-                reason=_('Image not in a supported format'))
+    except Exception:
+        raise exception.ImageUnacceptable(
+            image_id=image_href,
+            reason=_('Image not in a supported format'))
+    if disk_format in ('iso',) + ami_formats:
+        # ISO or AMI image passed safety check; qemu will treat this as raw
+        # from here so return the expected formats it will find.
+        disk_format = 'raw'
     return disk_format
 
 
@@ -192,12 +205,22 @@ def fetch_to_raw(context, image_href, path, trusted_certs=None):
 
         # Only run qemu-img after we have done deep inspection (if enabled).
         # If it was not enabled, we will let it detect the format.
-        data = qemu_img_info(path_tmp, format=force_format)
+        data = qemu_img_info(path_tmp)
         fmt = data.file_format
         if fmt is None:
             raise exception.ImageUnacceptable(
                 reason=_("'qemu-img info' parsing failed."),
                 image_id=image_href)
+        elif force_format is not None and fmt != force_format:
+            # Format inspector and qemu-img must agree on the format, else
+            # we reject. This will catch VMDK some variants that we don't
+            # explicitly support because qemu will identify them as such
+            # and we will not.
+            LOG.warning('Image %s detected by qemu as %s but we expected %s',
+                        image_href, fmt, force_format)
+            raise exception.ImageUnacceptable(
+                image_id=image_href,
+                reason=_('Image content does not match disk_format'))
 
         backing_file = data.backing_file
         if backing_file is not None:
